.. Matt's astro python toolbox documentation master file, created by
   sphinx-quickstart on Mon Dec 26 12:01:40 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

###################
MSUM python toolbox
###################

********
Contents
********

.. toctree::
   :maxdepth: 2

   overview
   installation
   scripts/automated_scripts
   scripts/manual_processing
   image_management
   header_processing/index
   xref
